@@ -22,7 +22,7 @@ async def update_color(latitude, longitude, leds, clouds, interval=5):
                 cloudy -= interval
                 asyncio.Task(warm.fade(0))
             else:
-                cloudy = int(random.random() < clouds) * random.randrange(
+                cloudy = int(random.random() < clouds) * random.randrange(  # nosec
                     0, max_cloud_duration, interval
                 )
                 asyncio.Task(warm.fade(1))
